@@ -4,7 +4,7 @@ import textwrap
 
 from . import Archive
 
-__version__ = 'wbsv 0.1.8'
+__version__ = 'wbsv 0.1.9'
 
 
 def parse_args():
@@ -47,13 +47,10 @@ def parse_args():
                         type=natural_num, metavar='lv',
                         help='Set maximum recursion depth.')
     args = parser.parse_args()
-    urls = []
-    for i in args.url:
-        if Archive.is_url(i):
-            urls.append(i)
-        else:
-            print("[!]invalid url format: {}".format(i), file=sys.stderr)
-            exit(1)
+    urls = [i for i in args.url if Archive.is_url(i)]
+    if args.url != urls:
+        print("[!]invalid url format", file=sys.stderr)
+        exit(1)
     param = {
         "retry": args.retry,
         "urls": urls,
