@@ -1,4 +1,5 @@
 from . import Archive
+from . import Find
 from . import ParseArgs
 from . import Interact
 
@@ -11,15 +12,15 @@ def main():
         Interact.interactive(opt)
 
     elif opt["only-target"]:
-        for x in opt["urls"]:
-            Archive.archive([x], x, opt["retry"])
+        [Archive.archive([x], x, opt["retry"]) for x in opt["urls"]]
+        exit(0)
+
     else:
         for x in opt["urls"]:
-            Archive.archive(Archive.extract_uri_recursive(
-                x, opt["level"]), x, opt["retry"])
+            dic = Find.extract_uri_recursive(x, opt["level"])
+            Archive.archive(dic, x, opt["retry"])
 
-    # if no errors occurred ...
-    exit(0)
+        exit(0)
 
 
 if __name__ == "__main__":
